==> test-env-generator-2.2.8.tgz: package/README.md <==
# Test env generator

[![Package Quality](https://npm.packagequality.com/badge/test-env-generator.png)](https://packagequality.com/#?package=test-env-generator)

[![DeepScan grade](https://deepscan.io/api/teams/4034/projects/5840/branches/46512/badge/grade.svg)](https://deepscan.io/dashboard#view=project&tid=4034&pid=5840&bid=46512)

[![BCH compliance](https://bettercodehub.com/edge/badge/AndriyNikiforov/test-env-generator?branch=dev-2.1)](https://bettercodehub.com/)

[![Maintainability](https://api.codeclimate.com/v1/badges/bdbceca56dcd9d789d61/maintainability)](https://codeclimate.com/github/AndriyNikiforov/test-env-generator/maintainability)

[![install size](https://packagephobia.now.sh/badge?p=test-env-generator)](https://packagephobia.now.sh/result?p=test-env-generator)

TEG is a tool for generate skeleton for fast start write tests.

## Installation

```npm install test-env-generator -D ```

## Usage

* Run generator with path where must be unzip ```teg <option> <path>```
* Run help comand ``` teg -h ```

Options
* selenium
* appium
* webdriver.io
* locus
* python selenium
* lighthouse (chrome dev tool for testing pages) + jest

## Help command

* ```teg info``` - show base information about commands

## HOW TO MAKE SCREENSHOT
[ABOUT](HOW_TO_MAKE_SCREENSHOT.md)

## CHROMEDRIVER OPTIONS
[OPTIONS](CONFIG_CHROMEDRIVER)

## CHANGELOG
[CHANGELOG](CHANGELOG.md)

## FUTURES
[FUTURES](FUTURES.md)

## License
[ISC](LICENSE.md)

## Contributing guide
[CONTRIBUTING](CONTRIBUTING.md)

## Api documentation
[API](API.md)

## Bugs
If you found bug or problem, please make issues in git repository. And if you can please make review my code.

## Code of conduct
[CODE_OF_CONDUCT](CODE_OF_CONDUCT.md)

## Pull request template
[PULL_REQUEST](PULL_REQUEST_TEMPLATE.md)

# Thanks for using

==> test-env-generator-2.5.1.tgz: package/README.md <==
# Test env generator

[![Package Quality](https://npm.packagequality.com/badge/test-env-generator.png)](https://packagequality.com/#?package=test-env-generator)

[![DeepScan grade](https://deepscan.io/api/teams/4034/projects/5840/branches/46512/badge/grade.svg)](https://deepscan.io/dashboard#view=project&tid=4034&pid=5840&bid=46512)

[![BCH compliance](https://bettercodehub.com/edge/badge/AndriyNikiforov/test-env-generator?branch=dev-2.1)](https://bettercodehub.com/)

[![Maintainability](https://api.codeclimate.com/v1/badges/bdbceca56dcd9d789d61/maintainability)](https://codeclimate.com/github/AndriyNikiforov/test-env-generator/maintainability)

[![install size](https://packagephobia.now.sh/badge?p=test-env-generator)](https://packagephobia.now.sh/result?p=test-env-generator)

TEG is a tool for generate skeleton for fast start write tests.

## Installation

```npm install test-env-generator -D ```

## Usage

* Run generator with path where must be unzip ```teg cli_name:cli```
* Run help comand ``` teg -h ```

CLI list:
* file
* git
* test

Available skeleton's
* selenium
* appium
* webdriver.io
* locus
* python selenium
* lighthouse (chrome dev tool for testing pages) + jest


## Help command

* ```teg ``` or ``` teg -h ``` - show base information about commands

## HOW TO MAKE SCREENSHOT
[ABOUT](HOW_TO_MAKE_SCREENSHOT.md)

## CHROMEDRIVER OPTIONS
[OPTIONS](CONFIG_CHROMEDRIVER)

## CHANGELOG
[CHANGELOG](CHANGELOG.md)

## FUTURES
[FUTURES](FUTURES.md)

## License
[ISC](LICENSE.md)

## Contributing guide
[CONTRIBUTING](CONTRIBUTING.md)

## Api documentation
[API](API.md)

## Bugs
If you found bug or problem, please make issues in git repository. And if you can please make review my code.

## Code of conduct
[CODE_OF_CONDUCT](CODE_OF_CONDUCT.md)

## Pull request template
[PULL_REQUEST](PULL_REQUEST_TEMPLATE.md)

# Thanks for using
